package com.ruoyi.bst.suit.service;

import java.util.List;

import com.ruoyi.bst.suit.domain.SuitQuery;
import com.ruoyi.bst.suit.domain.SuitVO;

/**
 * 套餐Service接口
 *
 * @author ruoyi
 * @date 2025-03-17
 */
public interface SuitService
{
    /**
     * 查询套餐
     *
     * @param id 套餐主键
     * @return 套餐
     */
    public SuitVO selectSuitById(Long id, boolean scope);

    default SuitVO selectSuitById(Long id) {
        return selectSuitById(id, false);
    }

    /**
     * 查询套餐列表
     *
     * @param suit 套餐
     * @return 套餐集合
     */
    public List<SuitVO> selectSuitList(SuitQuery suit);

    /**
     * 新增套餐
     *
     * @param suit 套餐
     * @return 结果
     */
    public int insertSuit(SuitVO suit);

    /**
     * 修改套餐
     *
     * @param suit 套餐
     * @return 结果
     */
    public int updateSuit(SuitVO suit);

    /**
     * 批量删除套餐
     *
     * @param ids 需要删除的套餐主键集合
     * @return 结果
     */
    public int deleteSuitByIds(List<Long> ids);


    /**
     * 查询单个套餐
     *
     * @param query 套餐查询条件
     * @return 套餐
     */
    public SuitVO selectOne(SuitQuery query);
}
